@@ -7,16 +7,16 @@
 #include <xmlrpc-c/c_util.h>
 
 /*
-  XMLRPC_LIBPP_EXPORTED marks a symbol in this file that is exported from
-  libxmlrpc++.
+XMLRPC_LIBUTILPP_EXPORTED marks a symbol in this file that is exported from
+libxmlrpc_util++.
 
-  XMLRPC_BUILDING_LIBPP says this compilation is part of libxmlrpc++, as
-  opposed to something that _uses_ libxmlrpc++.
+XMLRPC_BUILDING_LIBUTILPP says this compilation is part of libxmlrpc_util++, as
+opposed to something that _uses_ libxmlrpc_util++.
 */
-#ifdef XMLRPC_BUILDING_LIBPP
-#define XMLRPC_LIBPP_EXPORTED XMLRPC_DLLEXPORT
+#ifdef XMLRPC_BUILDING_LIBUTILPP
+#define XMLRPC_LIBUTILPP_EXPORTED XMLRPC_DLLEXPORT
 #else
-#define XMLRPC_LIBPP_EXPORTED
+#define XMLRPC_LIBUTILPP_EXPORTED
 #endif
 
 namespace xmlrpc_c {
@@ -24,14 +24,14 @@ namespace xmlrpc_c {
 
 enum newlineCtl {NEWLINE_NO, NEWLINE_YES};
 
-XMLRPC_LIBPP_EXPORTED
+XMLRPC_LIBUTILPP_EXPORTED
 std::string
 base64FromBytes(
     std::vector<unsigned char> const& bytes,
     xmlrpc_c::newlineCtl       const  newlineCtl = xmlrpc_c::NEWLINE_YES);
 
 
-XMLRPC_LIBPP_EXPORTED
+XMLRPC_LIBUTILPP_EXPORTED
 std::vector<unsigned char>
 bytesFromBase64(std::string const& base64);
 
